#
# spec file for package vhba-kmp
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           vhba-kmp
Version:        20240917
Release:        1.2
Summary:        Virtual SCSI Host Bus Adapter
License:        GPL-2.0-or-later
Group:          System/Kernel
URL:            https://cdemu.sourceforge.io/about/vhba/

#Git-Clone:	https://github.com/cdemu/cdemu
Source:         https://downloads.sf.net/cdemu/vhba-module-%version.tar.xz
Source2:        %name-preamble
Patch1:         vhba-no-werror.diff
Patch2:         vhba-devname.diff
Patch3:         vhba-sle-kernel.diff
BuildRequires:  %kernel_module_package_buildreqs
BuildRequires:  kernel-syms >= 2.6.20

%{?kernel_module_package:%kernel_module_package -n vhba -p %name-preamble}

%description
A Linux kernel module implementing a virtual SCSI Host Bus Adapter to
act as a low-level SCSI driver and which provides the SCSI layer with
a virtual SCSI adapter which can have multiple virtual devices. It is
part of the userspace cdemu suite, CD/DVD-ROM device emulator for
Linux.

%package KMP
Summary:        Virtual SCSI Host Bus adapter

%description KMP
A Linux kernel module implementing a virtual SCSI Host Bus Adapter to
act as a low-level SCSI driver and which provides the SCSI layer with
a virtual SCSI adapter which can have multiple virtual devices. It is
part of the userspace cdemu suite, CD/DVD-ROM device emulator for
Linux.

%prep
echo %flavors_to_build
%autosetup -n vhba-module-%version -p1

%build
%if 0%{?sle_version} >= 150500 && 0%{?sle_version} < 160000
export KCFLAGS="-DSLE"
%endif
for flavor in %flavors_to_build; do
	cp -a . "../obj-$flavor/"
	pushd "../obj-$flavor/"
	make KDIR="/usr/src/linux-obj/%_target_cpu/$flavor" \
		%{?_smp_mflags}
	popd
done

%install
export INSTALL_MOD_PATH="%buildroot"

for flavor in %flavors_to_build; do
	pushd "../obj-$flavor/"
	make KDIR="/usr/src/linux-obj/%_target_cpu/$flavor" \
		modules_install
	popd
done
# udev rules are packaged in cdemu-daemon.spec instead

%changelog
* Fri Oct 11 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 20240917
  * Linux 6.11 support
* Mon Feb 12 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 20240202
  * No user-visible changes
* Thu Apr 20 2023 Jan Engelhardt <jengelh@inai.de>
- Add vhba-sle-kernel.diff [boo#1206169]
* Mon Dec  5 2022 Ludwig Nussel <lnussel@suse.de>
- BuildRequire %%kernel_module_package_buildreqs (boo#1205149)
* Wed Jan 19 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20211218
  * Support for Linux 5.16 SCSI layer API updates
* Thu Nov 25 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 20211023
  * Support for Linux 5.15
* Tue Apr 20 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 20210418
  * vhba: Change how command matching and tagging is performed.
  * vhba: Use dynamic debugging for everything.
  * vhba: Handle command queue locking ourselves.
* Thu Mar 19 2020 Aaron Stern <ukbeast89@protonmail.com>
- Update to release 20200106
  * Added an ioctl to retrieve the global device number
* Thu Oct 17 2019 Jan Engelhardt <jengelh@inai.de>
- Update to release 20190831
  * Don't try to unload module from running kernel.
  * Add support for multiple SCSI channels.
  * Add proper support for scatterlist chaining.
* Mon Jul  1 2019 Aaron Stern <ukbeast89@ptotonmail.com>
-Update to new upstream release 20190410
  * Fixes crash when mounting disk image on linux 5.1
  * Remove vhba-scsiapi.diff, as upstream builds with linux 5.1
* Tue May 28 2019 Jan Engelhardt <jengelh@inai.de>
- Add vhba-scsiapi.diff to fix the build with Linux 5.1
* Mon Aug  7 2017 jengelh@inai.de
- Update to new upstream release 20170610
  * Support for Linux 4.11 (integrate vhba-signal.diff)
- Drop vhba-signal.diff (merged upstream)
* Wed May 17 2017 jengelh@inai.de
- Add vhba-signal.diff so it builds with Linux 4.11
* Mon Feb  6 2017 jengelh@inai.de
- Update to new upstream release 20161009
  * Documentation updates
* Wed Dec  9 2015 jengelh@inai.de
- Improve autoloading by editing vhba-devname.diff to assign a
  static misc number.
* Mon Nov 23 2015 jengelh@inai.de
- Add vhba-devname.diff
* Thu Oct  2 2014 jengelh@inai.de
- Update to new upstream release 20140928 (cdemu-3.0.2)
  * Work around a warning occurring in grsecurity kernels
* Sun Jul 13 2014 sor.alexei@meowr.ru
- Update to new upstream release 20140629 (cdemu-3.0.0)
  * CD image write support
* Sun Jun  9 2013 jengelh@inai.de
- Update to new upstream release 20130607 (cdemu-2.1.0)
  * Added support for non-blocking I/O.
  * Allow longer commands to be issues on VHBA.
  * Explicitly distinguish between device addition and device removal
  change, and resolve cases when both occur before rescan is done.
- Remove vhba-parallel-build.diff, vhba-pwd.diff (merged upstream)
* Sat Mar 30 2013 jengelh@inai.de
- Remove unused Supplements; use virtual modutils for building
* Tue May  8 2012 jengelh@inai.de
- Initial package for build.opensuse.org
